@@ -1,8 +1,8 @@
 <?php
 
 /**
- * This file is part of the Froxlor project.
- * Copyright (c) 2010 the Froxlor Team (see authors).
+ * This file is part of the froxlor project.
+ * Copyright (c) 2010 the froxlor Team (see authors).
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -19,7 +19,7 @@
  * https://files.froxlor.org/misc/COPYING.txt
  *
  * @copyright  the authors
- * @author     Froxlor team <team@froxlor.org>
+ * @author     froxlor team <team@froxlor.org>
  * @license    https://files.froxlor.org/misc/COPYING.txt GPLv2
  */
 
@@ -134,6 +134,35 @@ class Domains extends ApiCommand implements ResourceEntity
 		return $ipandports;
 	}
 
+	private function getHasCertValueForDomain(int $domainid, int $parentdomainid): int
+	{
+		// nothing (ssl_global)
+		$domain_hascert = 0;
+		$ssl_stmt = Database::prepare("SELECT * FROM `" . TABLE_PANEL_DOMAIN_SSL_SETTINGS . "` WHERE `domainid` = :domainid");
+		Database::pexecute($ssl_stmt, array(
+			"domainid" => $domainid
+		));
+		$ssl_result = $ssl_stmt->fetch(PDO::FETCH_ASSOC);
+		if (is_array($ssl_result) && isset($ssl_result['ssl_cert_file']) && $ssl_result['ssl_cert_file'] != '') {
+			// own certificate (ssl_customer_green)
+			$domain_hascert = 1;
+		} else {
+			// check if it's parent has one set (shared)
+			if ($parentdomainid != 0) {
+				$ssl_stmt = Database::prepare("SELECT * FROM `" . TABLE_PANEL_DOMAIN_SSL_SETTINGS . "` WHERE `domainid` = :domainid");
+				Database::pexecute($ssl_stmt, array(
+					"domainid" => $parentdomainid
+				));
+				$ssl_result = $ssl_stmt->fetch(PDO::FETCH_ASSOC);
+				if (is_array($ssl_result) && isset($ssl_result['ssl_cert_file']) && $ssl_result['ssl_cert_file'] != '') {
+					// parent has a certificate (ssl_shared)
+					$domain_hascert = 2;
+				}
+			}
+		}
+		return $domain_hascert;
+	}
+
 	/**
 	 * returns the total number of accessible domains
 	 *
@@ -145,17 +174,19 @@ class Domains extends ApiCommand implements ResourceEntity
 	{
 		if ($this->isAdmin()) {
 			$this->logger()->logAction(FroxlorLogger::ADM_ACTION, LOG_NOTICE, "[API] list domains");
+			$query_fields = [];
 			$result_stmt = Database::prepare("
 				SELECT
 				COUNT(*) as num_domains
 				FROM `" . TABLE_PANEL_DOMAINS . "` `d`
 				LEFT JOIN `" . TABLE_PANEL_CUSTOMERS . "` `c` USING(`customerid`)
 				LEFT JOIN `" . TABLE_PANEL_DOMAINS . "` `ad` ON `d`.`aliasdomain`=`ad`.`id`
-				WHERE `d`.`parentdomainid`='0' " . ($this->getUserDetail('customers_see_all') ? '' : " AND `d`.`adminid` = :adminid "));
+				WHERE `d`.`parentdomainid`='0' " . ($this->getUserDetail('customers_see_all') ? '' : " AND `d`.`adminid` = :adminid ") . $this->getSearchWhere($query_fields, true));
 			$params = [];
 			if ($this->getUserDetail('customers_see_all') == '0') {
 				$params['adminid'] = $this->getUserDetail('adminid');
 			}
+			$params = array_merge($params, $query_fields);
 			$result = Database::pexecute_first($result_stmt, $params, true, true);
 			if ($result) {
 				return $this->response($result['num_domains']);
@@ -246,6 +277,9 @@ class Domains extends ApiCommand implements ResourceEntity
 	 * @param bool $http2
 	 *            optional, whether to enable http/2 for this domain (requires to be enabled in the settings), default
 	 *            0 (false)
+	 * @param bool $http3
+	 *            optional, whether to enable http/3 for this domain (requires to be enabled in the settings), default
+	 *            0 (false)
 	 * @param int $hsts_maxage
 	 *            optional max-age value for HSTS header
 	 * @param bool $hsts_sub
@@ -274,8 +308,8 @@ class Domains extends ApiCommand implements ResourceEntity
 	 *            $override_tls is true
 	 * @param string $description
 	 *            optional custom description (currently not used/shown in the frontend), default empty
-	 * @param bool $is_stdsubdomain (internally)
-	 *            optional whether this is a standard subdomain for a customer which is being added so no usage is decreased
+	 * @param bool $is_stdsubdomain
+	 *            (internally) optional whether this is a standard subdomain for a customer which is being added so no usage is decreased
 	 * @access admin
 	 * @return string json-encoded array
 	 * @throws Exception
@@ -322,6 +356,7 @@ class Domains extends ApiCommand implements ResourceEntity
 				$dont_use_default_ssl_ipandport_if_empty = $this->getBoolParam('dont_use_default_ssl_ipandport_if_empty', true, 0);
 				$p_ssl_ipandports = $this->getParam('ssl_ipandport', true, $dont_use_default_ssl_ipandport_if_empty ? [] : explode(',', Settings::Get('system.defaultsslip')));
 				$http2 = $this->getBoolParam('http2', true, 0);
+				$http3 = $this->getBoolParam('http3', true, 0);
 				$hsts_maxage = $this->getParam('hsts_maxage', true, 0);
 				$hsts_sub = $this->getBoolParam('hsts_sub', true, 0);
 				$hsts_preload = $this->getBoolParam('hsts_preload', true, 0);
@@ -467,6 +502,21 @@ class Domains extends ApiCommand implements ResourceEntity
 					if (empty($ssl_protocols)) {
 						$override_tls = '0';
 					}
+
+					// http/3 for nginx only works with TLSv1.3 enabled
+					if ($http3 == '1') {
+						// overwrite enabled?
+						if (Settings::Get('system.webserver') != 'nginx') {
+							$http3 = '0';
+						} else {
+							if (($override_tls == '1' && !in_array('TLSv1.3', $ssl_protocols)) ||
+								($override_tls == '0' && !in_array('TLSv1.3', explode(",", Settings::Get('system.ssl_protocols'))))
+							) {
+								// no tlsv1.3 -> no http/3
+								Response::standardError('tls13requiredforhttp3', '', true);
+							}
+						}
+					}
 				} else {
 					$isbinddomain = '0';
 					if (Settings::Get('system.bind_enable') == '1') {
@@ -559,6 +609,7 @@ class Domains extends ApiCommand implements ResourceEntity
 					$ssl_redirect = 0;
 					$letsencrypt = 0;
 					$http2 = 0;
+					$http3 = 0;
 					// we need this for the json_encode
 					// if ssl is disabled or no ssl-ip/port exists
 					$ssl_ipandports[] = -1;
@@ -734,6 +785,7 @@ class Domains extends ApiCommand implements ResourceEntity
 						'mod_fcgid_maxrequests' => $mod_fcgid_maxrequests,
 						'letsencrypt' => $letsencrypt,
 						'http2' => $http2,
+						'http3' => $http3,
 						'hsts' => $hsts_maxage,
 						'hsts_sub' => $hsts_sub,
 						'hsts_preload' => $hsts_preload,
@@ -787,6 +839,7 @@ class Domains extends ApiCommand implements ResourceEntity
 						`mod_fcgid_maxrequests` = :mod_fcgid_maxrequests,
 						`letsencrypt` = :letsencrypt,
 						`http2` = :http2,
+						`http3` = :http3,
 						`hsts` = :hsts,
 						`hsts_sub` = :hsts_sub,
 						`hsts_preload` = :hsts_preload,
@@ -920,35 +973,6 @@ class Domains extends ApiCommand implements ResourceEntity
 		throw new Exception("Not allowed to execute given command.", 403);
 	}
 
-	private function getHasCertValueForDomain(int $domainid, int $parentdomainid): int
-	{
-		// nothing (ssl_global)
-		$domain_hascert = 0;
-		$ssl_stmt = Database::prepare("SELECT * FROM `" . TABLE_PANEL_DOMAIN_SSL_SETTINGS . "` WHERE `domainid` = :domainid");
-		Database::pexecute($ssl_stmt, array(
-			"domainid" => $domainid
-		));
-		$ssl_result = $ssl_stmt->fetch(PDO::FETCH_ASSOC);
-		if (is_array($ssl_result) && isset($ssl_result['ssl_cert_file']) && $ssl_result['ssl_cert_file'] != '') {
-			// own certificate (ssl_customer_green)
-			$domain_hascert = 1;
-		} else {
-			// check if it's parent has one set (shared)
-			if ($parentdomainid != 0) {
-				$ssl_stmt = Database::prepare("SELECT * FROM `" . TABLE_PANEL_DOMAIN_SSL_SETTINGS . "` WHERE `domainid` = :domainid");
-				Database::pexecute($ssl_stmt, array(
-					"domainid" => $parentdomainid
-				));
-				$ssl_result = $ssl_stmt->fetch(PDO::FETCH_ASSOC);
-				if (is_array($ssl_result) && isset($ssl_result['ssl_cert_file']) && $ssl_result['ssl_cert_file'] != '') {
-					// parent has a certificate (ssl_shared)
-					$domain_hascert = 2;
-				}
-			}
-		}
-		return $domain_hascert;
-	}
-
 	/**
 	 * validate given ips
 	 *
@@ -1148,6 +1172,9 @@ class Domains extends ApiCommand implements ResourceEntity
 	 * @param bool $http2
 	 *            optional, whether to enable http/2 for this domain (requires to be enabled in the settings), default
 	 *            0 (false)
+	 * @param bool $http3
+	 *            optional, whether to enable http/3 for this domain (requires to be enabled in the settings), default
+	 *            0 (false)
 	 * @param int $hsts_maxage
 	 *            optional max-age value for HSTS header
 	 * @param bool $hsts_sub
@@ -1236,6 +1263,7 @@ class Domains extends ApiCommand implements ResourceEntity
 			] : null);
 			$sslenabled = $remove_ssl_ipandport ? false : $this->getBoolParam('sslenabled', true, $result['ssl_enabled']);
 			$http2 = $this->getBoolParam('http2', true, $result['http2']);
+			$http3 = $this->getBoolParam('http3', true, $result['http3']);
 			$hsts_maxage = $this->getParam('hsts_maxage', true, $result['hsts']);
 			$hsts_sub = $this->getBoolParam('hsts_sub', true, $result['hsts_sub']);
 			$hsts_preload = $this->getBoolParam('hsts_preload', true, $result['hsts_preload']);
@@ -1461,6 +1489,21 @@ class Domains extends ApiCommand implements ResourceEntity
 				if (empty($ssl_protocols)) {
 					$override_tls = '0';
 				}
+
+				// http/3 for nginx only works with TLSv1.3 enabled
+				if ($http3 == '1') {
+					// overwrite enabled?
+					if (Settings::Get('system.webserver') != 'nginx') {
+						$http3 = '0';
+					} else {
+						if (($override_tls == '1' && !in_array('TLSv1.3', $ssl_protocols)) ||
+							($override_tls == '0' && !in_array('TLSv1.3', explode(",", Settings::Get('system.ssl_protocols'))))
+						) {
+							// no tlsv1.3 -> no http/3
+							Response::standardError('tls13requiredforhttp3', '', true);
+						}
+					}
+				}
 			} else {
 				$isbinddomain = $result['isbinddomain'];
 				$zonefile = $result['zonefile'];
@@ -1551,6 +1594,7 @@ class Domains extends ApiCommand implements ResourceEntity
 				$ssl_redirect = 0;
 				$letsencrypt = 0;
 				$http2 = 0;
+				$http3 = 0;
 				// act like $remove_ssl_ipandport
 				$ssl_ipandports = [];
 
@@ -1695,11 +1739,14 @@ class Domains extends ApiCommand implements ResourceEntity
 				|| ($speciallogfile != $result['speciallogfile'] && $speciallogverified == '1')
 				|| $letsencrypt != $result['letsencrypt']
 				|| $http2 != $result['http2']
+				|| $http3 != $result['http3']
 				|| $hsts_maxage != $result['hsts']
 				|| $hsts_sub != $result['hsts_sub']
 				|| $hsts_preload != $result['hsts_preload']
 				|| $ocsp_stapling != $result['ocsp_stapling']
 				|| $sslenabled != $result['ssl_enabled']
+				|| $override_tls != $result['override_tls']
+				|| implode(",", $ssl_protocols) != $result['ssl_protocols']
 			) {
 				Cronjob::inserttask(TaskId::REBUILD_VHOST);
 			}
@@ -1868,6 +1915,7 @@ class Domains extends ApiCommand implements ResourceEntity
 			$update_data['termination_date'] = $termination_date;
 			$update_data['letsencrypt'] = $letsencrypt;
 			$update_data['http2'] = $http2;
+			$update_data['http3'] = $http3;
 			$update_data['hsts'] = $hsts_maxage;
 			$update_data['hsts_sub'] = $hsts_sub;
 			$update_data['hsts_preload'] = $hsts_preload;
@@ -1916,6 +1964,7 @@ class Domains extends ApiCommand implements ResourceEntity
 				`termination_date` = :termination_date,
 				`letsencrypt` = :letsencrypt,
 				`http2` = :http2,
+				`http3` = :http3,
 				`hsts` = :hsts,
 				`hsts_sub` = :hsts_sub,
 				`hsts_preload` = :hsts_preload,
@@ -2022,7 +2071,7 @@ class Domains extends ApiCommand implements ResourceEntity
 				'id' => $id
 			], true, true);
 			$current_ips = [];
-			while ($cIP = $ip_sel_stmt->fetch(\PDO::FETCH_ASSOC)) {
+			while ($cIP = $ip_sel_stmt->fetch(PDO::FETCH_ASSOC)) {
 				$current_ips[] = $cIP['id_ipandports'];
 			}
 
