@@ -1,8 +1,8 @@
 <?php
 
 /**
- * This file is part of the Froxlor project.
- * Copyright (c) 2010 the Froxlor Team (see authors).
+ * This file is part of the froxlor project.
+ * Copyright (c) 2010 the froxlor Team (see authors).
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -19,12 +19,13 @@
  * https://files.froxlor.org/misc/COPYING.txt
  *
  * @copyright  the authors
- * @author     Froxlor team <team@froxlor.org>
+ * @author     froxlor team <team@froxlor.org>
  * @license    https://files.froxlor.org/misc/COPYING.txt GPLv2
  */
 
 namespace Froxlor\Install;
 
+use Froxlor\FileDir;
 use Froxlor\Froxlor;
 use Froxlor\FroxlorLogger;
 use Froxlor\Settings;
@@ -85,7 +86,7 @@ class Update
 				self::$update_tasks[self::$task_counter]['result'] = 1;
 				break;
 			default:
-                self::$update_tasks[self::$task_counter]['result'] = -1;
+				self::$update_tasks[self::$task_counter]['result'] = -1;
 				break;
 		}
 
@@ -136,4 +137,36 @@ class Update
 	{
 		return self::$task_counter;
 	}
+
+	public static function cleanOldFiles(array $to_clean)
+	{
+		self::showUpdateStep("Cleaning up old files");
+		$disabled = explode(',', ini_get('disable_functions'));
+		$exec_allowed = !in_array('exec', $disabled);
+		$del_list = "";
+		foreach ($to_clean as $filedir) {
+			$complete_filedir = Froxlor::getInstallDir() . $filedir;
+			if (file_exists($complete_filedir)) {
+				if ($exec_allowed) {
+					FileDir::safe_exec("rm -rf " . escapeshellarg($complete_filedir));
+				} else {
+					$del_list .= "rm -rf " . escapeshellarg($complete_filedir) . PHP_EOL;
+				}
+			}
+		}
+		if ($exec_allowed) {
+			self::lastStepStatus(0);
+		} else {
+			if (empty($del_list)) {
+				// none of the files existed
+				self::lastStepStatus(0);
+			} else {
+				self::lastStepStatus(
+					1,
+					'manual commands needed',
+					'Please run the following commands manually:<br><pre>' . $del_list . '</pre>'
+				);
+			}
+		}
+	}
 }
