@@ -1,8 +1,8 @@
 <?php
 
 /**
- * This file is part of the Froxlor project.
- * Copyright (c) 2010 the Froxlor Team (see authors).
+ * This file is part of the froxlor project.
+ * Copyright (c) 2010 the froxlor Team (see authors).
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -19,7 +19,7 @@
  * https://files.froxlor.org/misc/COPYING.txt
  *
  * @copyright  the authors
- * @author     Froxlor team <team@froxlor.org>
+ * @author     froxlor team <team@froxlor.org>
  * @license    https://files.froxlor.org/misc/COPYING.txt GPLv2
  */
 
@@ -35,7 +35,6 @@ return [
 		'sections' => [
 			'section_a' => [
 				'title' => lng('admin.accountdata'),
-				'image' => 'icons/user_edit.png',
 				'fields' => [
 					'loginname' => [
 						'label' => lng('login.username'),
@@ -91,7 +90,6 @@ return [
 			],
 			'section_b' => [
 				'title' => lng('admin.contactdata'),
-				'image' => 'icons/user_edit.png',
 				'fields' => [
 					'name' => [
 						'label' => lng('customer.name'),
@@ -123,7 +121,6 @@ return [
 			],
 			'section_c' => [
 				'title' => lng('admin.servicedata'),
-				'image' => 'icons/user_add.png',
 				'visible' => $result['adminid'] != $userinfo['userid'],
 				'fields' => [
 					'ipaddress' => [
