@@ -1,8 +1,8 @@
 <?php
 
 /**
- * This file is part of the Froxlor project.
- * Copyright (c) 2010 the Froxlor Team (see authors).
+ * This file is part of the froxlor project.
+ * Copyright (c) 2010 the froxlor Team (see authors).
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -19,7 +19,7 @@
  * https://files.froxlor.org/misc/COPYING.txt
  *
  * @copyright  the authors
- * @author     Froxlor team <team@froxlor.org>
+ * @author     froxlor team <team@froxlor.org>
  * @license    https://files.froxlor.org/misc/COPYING.txt GPLv2
  */
 
@@ -36,7 +36,6 @@ return [
 		'sections' => [
 			'section_a' => [
 				'title' => lng('admin.accountdata'),
-				'image' => 'icons/user_add.png',
 				'fields' => [
 					'new_loginname' => [
 						'label' => lng('login.username'),
@@ -97,11 +96,17 @@ return [
 						'checked' => Settings::Get('api.enabled') == '1' && Settings::Get('api.customer_default'),
 						'visible' => Settings::Get('api.enabled') == '1'
 					],
+					'shell_allowed' => [
+						'label' => lng('usersettings.shell_allowed.title'),
+						'desc' => lng('usersettings.shell_allowed.description'),
+						'type' => 'checkbox',
+						'value' => '1',
+						'visible' => Settings::Get('system.allow_customer_shell') == '1',
+					],
 				]
 			],
 			'section_b' => [
 				'title' => lng('admin.contactdata'),
-				'image' => 'icons/user_add.png',
 				'fields' => [
 					'gender' => [
 						'label' => lng('gender.title'),
@@ -179,7 +184,6 @@ return [
 			'section_cpre' => [
 				'visible' => !empty($hosting_plans),
 				'title' => lng('admin.plans.use_plan'),
-				'image' => 'icons/user_add.png',
 				'fields' => [
 					'use_plan' => [
 						'label' => lng('admin.plans.use_plan'),
@@ -190,7 +194,6 @@ return [
 			],
 			'section_c' => [
 				'title' => lng('admin.servicedata'),
-				'image' => 'icons/user_add.png',
 				'fields' => [
 					'diskspace' => [
 						'label' => lng('customer.diskspace') . ' (' . lng('customer.mib') . ')',
