@@ -1,8 +1,8 @@
 <?php
 
 /**
- * This file is part of the Froxlor project.
- * Copyright (c) 2010 the Froxlor Team (see authors).
+ * This file is part of the froxlor project.
+ * Copyright (c) 2010 the froxlor Team (see authors).
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -19,7 +19,7 @@
  * https://files.froxlor.org/misc/COPYING.txt
  *
  * @copyright  the authors
- * @author     Froxlor team <team@froxlor.org>
+ * @author     froxlor team <team@froxlor.org>
  * @license    https://files.froxlor.org/misc/COPYING.txt GPLv2
  */
 
@@ -31,7 +31,6 @@ return [
 		'sections' => [
 			'section_a' => [
 				'title' => lng('admin.fpmsettings.edit'),
-				'image' => 'icons/phpsettings_edit.png',
 				'fields' => [
 					'description' => [
 						'label' => lng('admin.phpsettings.description'),
@@ -45,7 +44,8 @@ return [
 						'type' => 'text',
 						'maxlength' => 255,
 						'value' => $result['reload_cmd'],
-						'mandatory' => true
+						'mandatory' => true,
+						'required_otp' => true
 					],
 					'config_dir' => [
 						'label' => lng('serversettings.phpfpm_settings.configdir'),
