@@ -1,15 +1,15 @@
 <?php
 
 /**
- * This file is part of the Froxlor project.
- * Copyright (c) 2010 the Froxlor Team (see authors).
+ * This file is part of the froxlor project.
+ * Copyright (c) 2010 the froxlor Team (see authors).
  *
  * For the full copyright and license information, please view the COPYING
  * file that was distributed with this source code. You can also view the
  * COPYING file online at https://files.froxlor.org/misc/COPYING.txt
  *
  * @copyright  (c) the authors
- * @author         Froxlor team <team@froxlor.org> (2010-)
+ * @author         froxlor team <team@froxlor.org> (2010-)
  * @license        GPLv2 https://files.froxlor.org/misc/COPYING.txt
  * @package        Formfields
  */
@@ -20,12 +20,11 @@ use Froxlor\System\Crypt;
 return [
 	'ftp_edit' => [
 		'title' => lng('ftp.account_edit'),
-		'image' => 'icons/user_edit.png',
+		'image' => 'fa-solid fa-pen',
 		'self_overview' => ['section' => 'ftp', 'page' => 'accounts'],
 		'sections' => [
 			'section_a' => [
 				'title' => lng('ftp.account_edit'),
-				'image' => 'icons/user_edit.png',
 				'fields' => [
 					'username' => [
 						'label' => lng('login.username'),
@@ -63,7 +62,7 @@ return [
 						]
 					],
 					'shell' => [
-						'visible' => Settings::Get('system.allow_customer_shell') == '1',
+						'visible' => Settings::Get('system.allow_customer_shell') == '1' && $user_shell_allowed,
 						'label' => lng('panel.shell'),
 						'type' => 'select',
 						'select_var' => $shells,
